import re

class Usarre:
	def __init__(self):
		self.arquivo = open("titulocorpo_tags.json", "r+t")
		self.texto = self.arquivo.readlines()

		self.modelandotags = ''
		for self.x in self.texto:
			self.modelandotags += self.x.strip('\n \t')


		self.hirafurikanji = re.findall(r'[\w\.]', self.modelandotags)
		self.pala = ''
		for self.x in self.hirafurikanji:
			self.pala += self.x

		self.sspan = re.findall(r'[^span]', self.pala)
		self.ssjunta = ''
		for self.x in self.sspan:
			self.ssjunta += self.x

		self.resupalaa= re.sub(r'[rubyrtspan W m l"href" "id0002" "javascript:void(0)" "id0001" "colorC" "colorL" "__" \s]','-', self.ssjunta) 

		self.resultadoka=re.findall(r'----(\w+)',self.resupalaa) 
	
		self.juntakhka = ''

		for self.x in self.resultadoka:
			self.juntakhka += self.x

		with open('pesquisanesemfuria.json', 'w') as self.semfuri:
		    self.semfuri.write(str(self.juntakhka))

		#cria arquivo para o artigo que vai ser gerado no criandopdf
		self.juntando = ''
		for self.x in self.resultadoka:
			self.juntando += self.x

		with open('newsartigo.txt', 'w') as self.sfuri:
		    self.sfuri.write(str(self.juntando))

#Usarre()



import requests
from bs4 import BeautifulSoup
import json
import csv

#inicio: importando funções de arquivos locais
from nwe.muitoslinks import Plinks
from nwe.muitoslinks import Pespalavra
#final: importando funções de arquivos locais


class Jisho:
	def __init__(self):
		self.arquivo = open("pesquisanesemfuria.json", "r")
		self.linha = self.arquivo.readlines()
		
		self.pesquisa = ''
		for self.x in self.linha:
			self.pesquisa += self.x


		# Cria variavel para armazenar a URL do site a ser raspado 最後学校答え中学校外国人必要韓国語質問
		self.url = 'https://jisho.org/search/'+self.pesquisa
			
		
		# Executa a requisição ao site e armazena o retorno na variavel
		self.resp = requests.get(self.url)
		self.resp.encoding = "UTF-8" #trazer os caracteres japoneses sem erros

		self.soup = BeautifulSoup(self.resp.text, 'html.parser')
		

		self.mui_palavras = self.soup.find('section', id='zen_bar') #aqui ele vai procurar por essa tag section e id, ela só vai existe se for mandado mais de uma palavra para pesquisa no jisho



		if self.mui_palavras == None: #aqui vai verificar o resuldo do 'find' se tiver sido só uma palavra pesquisada, o resultado armazenado na variavel 'mui_palavras' vai ser 'None' ou seja não tem lista ai não vai procurar os outros links das palavras.
			self.resultado_list = self.soup.find(class_='concept_light-meanings medium-9 columns')
			self.resultado_furigana = self.soup.find(class_='concept_light-readings japanese japanese_gothic')#class="concept_light-wrapper columns zero-paddingconcept_light-readings japanese japanese_gothic"
			self.pesump = Pespalavra()
			self.a = self.pesump.pespalavra(self.resultado_list)
			self.b = self.pesump.kanjifuri(self.resultado_furigana)
			
			self.tamanhoa = len(self.a)
			self.tamanhob = len(self.b)
			self.indice = 0 #pega os item da lista
			with open('palavras01.csv', 'w') as self.arquivo_csv:
			    self.colunas = ['listaingles', 'furigana;kanji']    
			    self.escrever = csv.DictWriter(self.arquivo_csv, fieldnames=self.colunas, delimiter=',', lineterminator='\n')
			    self.escrever.writeheader()	 
			    for self.x in self.a: #vai pecorrer a lista 'a' 
			    	self.letraa = str(self.x)
			    	if self.indice < self.tamanhob: #para ir adicionando a lista 'b' eu crio uma variavel 'indice' de valor igual a 0, e aumento ela em 1, quando chegar a um valor em que for igual a lista 'b' ela para e vai para o 'else'
			    		self.item = self.b[self.indice]
				    	self.itemm = str(self.item)
				    	self.escrever.writerow({'listaingles': self.letraa, 'furigana;kanji': self.itemm})
				    	self.indice =+ 1
			    	else:
			    		self.itemm = 'não tem item'
			    		self.escrever.writerow({'listaingles': self.letraa, 'furigana;kanji': self.itemm})
			    		self.indice =+ 1

		else:
			self.liste = self.mui_palavras.find_all('li', 'clearfix japanese_word')
			self.resultado_furigana = self.soup.find(class_='concept_light-readings japanese japanese_gothic')
			self.pesquisalinks = Plinks(self.liste)
			self.a = self.pesquisalinks.imprimilista()
			self.b = []
			for self.x in self.a:
				self.b.append(self.x)
			self.linkspala = self.pesquisalinks.gerapesquisa()
			self.pes = Pespalavra()
			self.s = self.pes.pesquisaVP(self.b)

			with open('palavras02.csv', 'w') as self.arquivo_csv:
			    self.colunas = ['listaingles', 'furigana;kanji']    
			    self.escrever = csv.DictWriter(self.arquivo_csv, fieldnames=self.colunas, delimiter=',', lineterminator='\n')
			    self.escrever.writeheader()
			    self.indice = 0
			    self.itemm = 'itemm vazio'
			    self.letraa ='letraa vazio'
			    for self.x in self.s: #vai pecorrer a lista 'a' 
			    	if self.indice % 2 == 0:
			    		self.itemm = ''
			    		for self.l in self.x:
			    			self.itemm += self.l+' ' #separar o kanji e o furigana na hora de salvar na coluna do arquivo csv
			    		self.itemm = self.itemm[:-1] #exclui o ultimo " "
			    		
			    		self.escrever.writerow({'listaingles': self.letraa, 'furigana;kanji': self.itemm})	
			    		self.indice += 1
			    	else:
			    		self.letraa = self.x[0]
			    		self.indice += 1


from reportlab.pdfgen import canvas
from reportlab.pdfbase import pdfmetrics
from reportlab.pdfbase.cidfonts import UnicodeCIDFont
from reportlab.lib.pagesizes import letter
from reportlab.lib.units import inch

from reportlab.lib.styles import getSampleStyleSheet
from reportlab.platypus import (SimpleDocTemplate, Paragraph, PageBreak)
from reportlab.lib.styles import ParagraphStyle as PS

#from reportlab.lib.pagesizes import A4
import csv

pdfmetrics.registerFont(UnicodeCIDFont('HeiseiMin-W3'))

class Umupdf:
    def __init__(self):
        self.bd = []
        self.bdni = []
        self.bdsan = []
        self.bdyon = {}
        self.elementos = []
        self.fonte = PS(name='fonte1', fontSize=14, fontName='HeiseiMin-W3', spaceBefore=8, spaceAfter=8, leading=16)
        with open('newsartigo.txt', 'r') as self.arquivo_txt:
            self.artigo = self.arquivo_txt.readlines()
        #print(self.artigo)
        for line in self.artigo:
            self.elementos.append(Paragraph(line, self.fonte))

        with open('palavraspdf.csv', 'r') as self.arquivo_csv:
            self.leitor = csv.DictReader(self.arquivo_csv, delimiter=',')
            for coluna in self.leitor:
                self.bd.append(coluna['listaportugues'])
                self.bdni.append(coluna['furigana;kanji'])
        self.tamanhobd = len(self.bd)
        self.tamanhobdni = len(self.bdni)
        self.valor = 1
        #print(self.tamanhobdni)
        for x in range(1,self.tamanhobdni):
            self.bdyon[self.bdni[x]] = self.bd[x]
        
        #self.fonte = PS(name='fonte1', fontSize=14, fontName='HeiseiMin-W3', spaceBefore=8)
        self.estilo = getSampleStyleSheet()
        #self.elementos = []

        for kanji,portugues in self.bdyon.items():
            self.elementos.append(Paragraph('{} : {}'.format(kanji,portugues), self.fonte))
       
        self.docpdf = SimpleDocTemplate("nwe.pdf", pagesize=letter, title='GifuNI', author='narutoolavo')
        self.docpdf.build(self.elementos)


#Umupdf()


import requests
from bs4 import BeautifulSoup
import json

class News:
	def __init__(self, url):
		self.urls = url
		self.resp = requests.get(self.urls)
		self.resp.encoding = "UTF-8"

		self.soup = BeautifulSoup(self.resp.text, 'html.parser')

		self.titulo = self.soup.find(class_='article-main__title')
		self.textocorpo = self.soup.find(class_='article-main__body article-body')

		self.tituloo = self.titulo.prettify()
		self.textocorpoo = self.textocorpo.prettify()
		self.listano = self.tituloo + self.textocorpoo


		with open('titulocorpo_tags.json', 'w') as self.tbody:
		    self.tbody.write(str(self.listano))


#!/usr/bin/env python3
import os.path
from setuptools import setup

with open('README.rst', 'rb') as file:
    readme = file.read().decode('utf8')
    
setup(
    name='nwe',
    version='1.0.1',
    url='https://github.com/narutolavo/nwe',
    license='MIT License',
    author='Narutolavo',
    author_email='narutoolavo@outlook.com',
    keywords='News Web Easy, Jisho, Anki, Japonês',
    description='Criar Cartões do anki e pdf, do site News Web Easy ',
    long_description=readme,
    packages=['nwe'],
    install_requires=['googletrans==4.0.0rc1', 'beautifulsoup4', 'reportlab'],
     entry_points={
        'gui_scripts': [
            'nwe = nwe:__main__',
        ]
    },
    classifiers=['Development Status :: 5 - Production/Stable',
                     'Intended Audience :: Education',
                     'Intended Audience :: End Users/Desktop',
                     'License :: OSI Approved :: MIT License',
                     'Operating System :: POSIX',
                     'Operating System :: Microsoft :: Windows',
                     'Operating System :: MacOS :: MacOS X',
                     'Topic :: Education',
                     'Programming Language :: Python',
                     'Programming Language :: Python :: 3',
                     'Programming Language :: Python :: 3.6',
                     'Programming Language :: Python :: 3.7',
                     'Programming Language :: Python :: 3.8'],
                     )


import requests
from bs4 import BeautifulSoup
"""Essa classe é para pegar uma lista gerada pela função find_all, com as tags 'li', ai depois procurar os links e tira os href para poder pesquisar as palavras.
ai gera um dicionario com as palavras para pesquisa elas"""
class Plinks:
	"""docstring for ClassName"""

	def __init__(self, value = []):
		self.liste2 = []
		self.juntar(value)
		self.listalink = []
		for self.x in self.liste2: #pega os links das pesquisas
			self.y = self.x.find_all('a') #aqui vai lá e pega todas as tags 'a' que no caso é só uma
			for self.x in self.y: #aqui vou anda na lista gerada pelo 'find_all'
				self.armazena = self.x['href']
				self.listalink.append(self.armazena)
		self.a = self.listalink
		#return self.listalink

	def imprimilista(self):
		return (self.a)

	def gerapesquisa(self): #aqui pega so os links
		self.item = 'link'
		self.valores = '0'
		self.listaaa = []
		self.dicio = {}
		while self.listalink:
			self.valor = len(self.listalink) #pega o tamanho da lista
			self.valores = str(self.valor) #aqui pego o tamanho da lista por exemplo 4, coverto par 'string' e armazeno em valores
			self.criav = self.item+self.valores #aqui eu junto o nome 'link' armazenado na variavel 'item' para criar uma variavel tipo 'link4'
			self.veiodlis = self.listalink.pop(0) #aqui eu pego o primeiro item da lista e armazeno na variavel 'veiodlis'
			self.dicio [self.criav] = self.veiodlis #aqui eu junto tudo, crio o dicionario com o 'link4' e o link da lista
			self.listaaa.append(self.criav) #aqui vou adicionando os 'link@(numeros), link4'

	def gerandol(self):
		return listaaa

	def juntar(self, value): #ao criar a liste2 vazia que é para alocar os links tem que juntar eles nela.
		for x in value:
			if not x in self.liste2:
				self.liste2.append(x)

class Pespalavra:
			
			def pespalavra(self, resultado_list):
				
				self.colocarf_csv = [] #pra colocar as palavras da tradução do jisho
				self.resultado_listi = resultado_list
				self.numerodeclass = self.resultado_listi.find_all(class_='meaning-meaning') #pega todas as traduçoes em ingles que o dicionario gera
				self.numerodetraduçao = len(self.numerodeclass) #pega o numero de traduçao

				self.lii = 0
				while self.lii < self.numerodetraduçao: 
					self.uma_p = self.numerodeclass[self.lii].get_text()
					
					self.colocarf_csv.append(self.uma_p)
					self.lii = self.lii + 1
				return self.colocarf_csv
				
			def kanjifuri(self, resultado_furigana): #aqui vai pegar a leitura(furigana) e a palavra em kanji
				self.resultado_furi = resultado_furigana
				self.lista_a_csv = []
				self.lista_r_space = []
				self.furigana = self.resultado_furi.find(class_='furigana')
				self.textkanji = self.resultado_furi.find(class_='text')
				self.botalista0 = self.furigana.get_text()
				self.botalista1 = self.textkanji.get_text()

				self.botalista4 = self.botalista0.split('\n') + self.botalista1.split('\n')
				self.botalista5 = self.botalista0.split('\n')

				self.botalista = self.furigana.get_text('\n') + self.textkanji.get_text('\n')
				
				self.listasemespaco = []
				for x in self.botalista4:
					self.listasemespaco.append(x.strip('\n \t'))
				self.listasemspace = []
				
				self.lspace = 0
				for x in self.listasemespaco:
					if x == '' or x == '      ':
						self.lspace += 1
						#print("vazio")
					else:
						self.listasemspace.append(x)
				return self.listasemspace
			def pesquisaVP(self, value = []):
				self.listaregula = ['n', 'a', 'r', 'u', 't', 'o' ]
				self.matrizes = [] #vai armazenar todas as listas da da função 'pespalavra e kanjifuri' que vem da soups para poder retorna para criar os arquivos csv
				self.matrizes.append(self.listaregula)
				self.listamarzena = []
				self.lista_li_recebida = [] #cria a lista responsavel por armazena os links
				self.junta(value) #aqui chama a função 'juntar' que pega a lista que vem e passa para a lista 'lista_li_recebida'

				for self.links in self.lista_li_recebida: #aqui vai pega cada link para pesquisa na url
					self.url = 'https://jisho.org'+self.links
					self.soupPes(self.url)
				return self.matrizes

			def soupPes(self, url): #aqui vai pesquisa a url
				self.resp = requests.get(url)
				self.resp.encoding = "UTF-8" #trazer os caracteres japoneses sem erros
				self.soup = BeautifulSoup(self.resp.text, 'html.parser')
				self.resultado_list = self.soup.find(class_='concept_light-meanings medium-9 columns')
				self.resultado_furigana = self.soup.find(class_='concept_light-readings japanese japanese_gothic')
				
				self.nenhumap = 0
				if self.resultado_list == None: #se não ouver uma palavra correspondente no jisho, o 'find' pode vim sem resultado o 'None'.
					#print("Não foi possível encontrar nenhuma palavra correspondente")
					self.nenhumap += 1
				else:
					self.listasoup = self.pespalavra(self.resultado_list) #chama a principal para retorna apenas a lista de palavras
					self.matrizes.append(self.listasoup)
					self.listakan = self.kanjifuri(self.resultado_furigana)
					self.matrizes.append(self.listakan)

			def junta(self, value): #ao criar a liste2 vazia que é para alocar os links tem que juntar eles nela.
				for x in value:
					
					if not x in self.lista_li_recebida:
						self.lista_li_recebida.append(x)
										
										



import tkinter as tk
from tkinter import ttk
#pacotes nwe
from nwe.newswebeasy import News
from nwe.usandore import Usarre
from nwe.jisho import Jisho
from nwe.filecsvgoogle import Criarpdf
from nwe.criandopdf import Umupdf
from nwe.criaanki import Crianki

class Tela:

	def __init__(self, master):

		self.nossatela = master

		#self.coisa = tk.nomdedowidget(widgetpai. opçoesdeconfiguraçao)
		self.nossatela.title("nwe")
		self.nossatela.geometry("500x200+200+100")

		#self.nossatela.wm_iconbitmap("@ne.xbm") 

		self.frame = tk.Frame(self.nossatela)
		self.frame.pack()

		self.frame2 = tk.Frame(self.nossatela)
		self.frame2.pack()

		self.frame3 = tk.Frame(self.nossatela)
		self.frame3.pack()

		self.frame4 = tk.Frame(self.nossatela)
		self.frame4.pack()

		self.texto = tk.Label(self.frame2, text="Insira o link: ")
		self.texto.pack(side=tk.LEFT, pady=10)


		self.entrada = tk.Entry(self.frame2)
		self.entrada.pack(side=tk.LEFT, pady=10, padx=10)
		

		self.botao = tk.Button(self.frame2, text="Iniciar", font=("Verdana", "14"), command=self.respostabotao)
		self.botao.pack()

		self.botao2 = tk.Button(self.frame4, text="Gerar PDF", font=("Verdana", "14"), command=self.gerarpdf)
		self.botao2.pack()

		self.botao3 = tk.Button(self.frame4, text="Criar Anki", font=("Verdana", "14"), command=self.cardanki)
		self.botao3.pack()

		self.barradeprogresso = ttk.Progressbar(self.frame3, length=200)
		self.barradeprogresso.pack()		

		self.textoaguarde = tk.Label(self.frame3, text=" ")
		self.textoaguarde.pack()

		self.label = tk.Label(self.frame, text="NWE", font=("Verdana", "20"))
		self.label.pack()

	def upbarraprogresso(self, valor):
		self.valore = valor
		self.barradeprogresso["value"] = self.valore
		self.barradeprogresso["maximum"] = 4
		self.barradeprogresso.update()
		if self.barradeprogresso["value"] == 4:
			self.textoaguarde["text"] = "Você já pode gerar o Pdf"


	def respostabotao(self):
		self.textoaguarde["text"] = "Aguarde..."
		self.valor = 0

		self.link = self.entrada.get()
		News(self.link)
		self.valor += 1
		self.upbarraprogresso(self.valor)

		Usarre()
		self.valor += 1
		self.upbarraprogresso(self.valor)

		Jisho()
		self.valor += 1
		self.upbarraprogresso(self.valor)

		Criarpdf()
		self.valor += 1
		self.upbarraprogresso(self.valor)

	def gerarpdf(self):
		self.barradeprogresso.stop()
		Umupdf()
		self.textoaguarde["text"] = "Arquivo Pdf gerado..."

	def cardanki(self):
		Crianki()
		self.textoaguarde["text"] = "Cartão Anki gerado..."



#gerar a nossa interface
def main():
	Janelaraiz = tk.Tk()

	Tela(Janelaraiz)

	Janelaraiz.mainloop()





from googletrans import Translator
translator = Translator()
import csv

class Criarpdf:
	def __init__(self):				
		self.bd = []
		self.bdni = []
		self.bdsan = []
		with open('palavras02.csv', 'r') as self.arquivo_csv:
		    self.leitor = csv.DictReader(self.arquivo_csv, delimiter=',')
		    for coluna in self.leitor:
		        self.bd.append(coluna['listaingles'])
		        self.bdni.append(coluna['furigana;kanji'])

		for x in self.bd:
			try:
				self.item = str(x)	
				self.traduzi = translator.translate(self.item, dest='pt')
				self.traduzir = str(self.traduzi.text)
				self.controlando = self.traduzir
				self.bdsan.append(self.controlando)
			except TypeError:
				#print("'NoneType' object is not iterable") As traduções variam de acordo com o gênero das palavras
				self.controlando = self.item + "(As traduções variam)"
				self.bdsan.append(self.controlando)



		self.tamanhobdsan = len(self.bdsan)#a
		self.tamanhobdni = len(self.bdni)#b
		self.indice = 0 #pega os item da lista
		with open('palavraspdf.csv', 'w') as self.arquivo_csv:
			self.colunas = ['listaportugues', 'furigana;kanji']    
			self.escrever = csv.DictWriter(self.arquivo_csv, fieldnames=self.colunas, delimiter=',', lineterminator='\n')
			self.escrever.writeheader()	 
			for x in self.bdsan: #vai pecorrer a lista 'bdsan' 
				self.letraa = str(x)
				if self.indice < self.tamanhobdni: #para ir adicionando a lista 'bdni' eu crio uma variavel 'indice' de valor igual a 0, e aumento ela em 1, quando chegar a um valor em que for igual a lista 'b' ela para e vai para o 'else'
					self.item = self.bdni[self.indice]
					self.itemm = str(self.item)
					self.escrever.writerow({'listaportugues': self.letraa, 'furigana;kanji': self.itemm})
					self.indice += 1
				else:
					self.itemm = 'não tem item'
					self.escrever.writerow({'listaportugues': self.letraa, 'furigana;kanji': self.itemm})
					self.indice += 1

#Criarpdf()


import csv

class Crianki:
	def __init__(self):
		self.bd = []
		self.bdni = []
		self.bdsan = []
		self.bdyon = {}
		with open('palavraspdf.csv', 'r') as self.arquivo_csv:
			self.leitor = csv.DictReader(self.arquivo_csv, delimiter=',')
			for coluna in self.leitor:
				self.bd.append(coluna['listaportugues'])
				self.bdni.append(coluna['furigana;kanji'])

		self.tamanhobd = len(self.bd)
		self.tamanhobdni = len(self.bdni)
		for x in range(1,self.tamanhobdni):
			self.bdyon[self.bdni[x]] = self.bd[x]


		'''for kanji,portugues in self.bdyon.items():
			self.bdsan.append('{} : {}'.format(kanji,portugues))'''

		with open('anki.txt', 'w') as self.arquivo_csv:
			self.colunas = ['furiganakanji', 'listaportugues']    
			self.escrever = csv.DictWriter(self.arquivo_csv, fieldnames=self.colunas, delimiter=',', lineterminator='\n')
			self.escrever.writeheader()

			for kanji,portugues in self.bdyon.items():
				self.escrever.writerow({'furiganakanji': kanji, 'listaportugues': portugues})

#Crianki()